API docs for “spamfighter.core.model.test.test_command.ModelBaseCommandTestCase”

# Class s.c.m.t.t.ModelBaseCommandTestCase(unittest.TestCase):

Part of spamfighter.core.model.test.test_command View Source View In Hierarchy

Тест на `spamfighter.core.model.command.ModelBaseCommand`.

Method | setUp | Undocumented
Method | tearDown | Undocumented
Method | testNoSuchModel | Undocumented
Method | testNotAModel | Undocumented
Method | testGetModel | Undocumented
Method | testGetNoText | Undocumented
Method | testGetText1 | Undocumented
Method | testGetText2 | Undocumented

def setUp(self): (source)
Undocumented
def tearDown(self): (source)
Undocumented
def testNoSuchModel(self): (source)
Undocumented
def testNotAModel(self): (source)
Undocumented
def testGetModel(self): (source)
Undocumented
def testGetNoText(self): (source)
Undocumented
def testGetText1(self): (source)
Undocumented
def testGetText2(self): (source)
Undocumented